==> alibabacloud_cloudauth-intl20220809-3.8.0.tar.gz: alibabacloud_cloudauth-intl20220809-3.8.0/ChangeLog.md <==
2025-06-26 Version: 3.7.2
- Update API Initialize: add request parameters ChameleonFrameEnable.


2025-06-16 Version: 3.7.1
- Update API DocOcrMax: add request parameters IdSpoof.
- Update API Initialize: add request parameters Pages.


2025-05-26 Version: 3.7.0
- Support API BankMetaVerifyIntl.


2025-05-20 Version: 3.6.1
- Update API Initialize: add response parameters Body.Result.Protocol.


2025-04-28 Version: 3.6.0
- Support API DocOcrMax.


2025-04-24 Version: 3.5.0
- Support API CredentialVerifyIntl.


2025-04-23 Version: 3.4.2
- Update API Initialize: add request parameters DateOfBirth.
- Update API Initialize: add request parameters DateOfExpiry.
- Update API Initialize: add request parameters DocPageConfig.
- Update API Initialize: add request parameters DocumentNumber.
- Update API Initialize: add request parameters MRTDInput.
- Update API Initialize: add request parameters UseNFC.


2025-04-21 Version: 3.4.1
- Generated python 2022-08-09 for Cloudauth-intl.

2025-04-21 Version: 3.4.0
- Support API CheckVerifyLog.
- Support API DeepfakeDetectIntl.
- Update API FaceGuardRisk: add response parameters Body.Result.GuardRiskScore.


2025-01-09 Version: 3.2.0
- Support API Id2MetaPeriodVerifyIntl.


2025-01-09 Version: 3.1.2
- Generated python 2022-08-09 for Cloudauth-intl.

2024-12-06 Version: 3.1.1
- Update API DocOcr: add param CardSide.
- Update API Initialize: add param AppQualityCheck.


2024-11-21 Version: 3.1.0
- Support API FaceGuardRisk.
- Update API CheckResult: update response param.
- Update API Initialize: add param ProcedurePriority.


2024-10-08 Version: 3.0.0
- Delete API DescribeAddressLabels.
- Delete API DescribeAddressOverview.
- Delete API DescribeMaliciousAddress.
- Delete API DescribeRiskScore.
- Delete API DescribeTransactionsList.
- Delete API DescribeWeb3AddressLabels.
- Delete API DescribeWeb3RiskScore.
- Delete API DescribeWeb3TransactionLabels.
- Update API Initialize: add param ShowGuidePage.


2024-08-29 Version: 2.0.4
- Update API FaceLiveness: update response param.


2024-08-23 Version: 2.0.3
- Update API Initialize: add param ShowAlbumIcon.
- Update API Initialize: add param ShowOcrResult.


2024-06-28 Version: 2.0.2
- Update API DocOcr: add param IdThreshold.
- Update API EkycVerify: add param IdThreshold.
- Update API Initialize: add param DocVideo.
- Update API Initialize: add param IdThreshold.
- Update API Initialize: add param Model.


2024-06-20 Version: 2.0.1
- Update API Initialize: add param ExperienceCode.


2024-04-25 Version: 2.0.0
- Delete API DeletePicture.
- Update API CheckResult: update response param.
- Update API DocOcr: update param IdOcrPictureBase64.
- Update API DocOcr: update param IdOcrPictureUrl.
- Update API DocOcr: update response param.
- Update API EkycVerify: update param DocName.
- Update API EkycVerify: update param DocNo.
- Update API EkycVerify: update param FacePictureBase64.
- Update API EkycVerify: update param FacePictureUrl.
- Update API EkycVerify: update param IdOcrPictureBase64.
- Update API EkycVerify: update param IdOcrPictureUrl.
- Update API EkycVerify: update response param.
- Update API FaceCompare: update param SourceFacePicture.
- Update API FaceCompare: update param SourceFacePictureUrl.
- Update API FaceCompare: update param TargetFacePicture.
- Update API FaceCompare: update param TargetFacePictureUrl.
- Update API FaceLiveness: update param FacePictureBase64.
- Update API FaceLiveness: update param FacePictureUrl.
- Update API FaceLiveness: update response param.
- Update API Id2MetaVerifyIntl: update param IdentifyNum.
- Update API Id2MetaVerifyIntl: update param UserName.
- Update API Initialize: add param StyleConfig.
- Update API Initialize: delete param FlowType.
- Update API Initialize: delete param OperationMode.
- Update API Initialize: delete param Pages.
- Update API Initialize: delete param ProductConfig.
- Update API Initialize: delete param ServiceLevel.
- Update API Initialize: update param FacePictureBase64.
- Update API Initialize: update param FacePictureUrl.
- Update API Mobile3MetaVerifyIntl: update param IdentifyNum.
- Update API Mobile3MetaVerifyIntl: update param Mobile.
- Update API Mobile3MetaVerifyIntl: update param UserName.


2024-02-04 Version: 1.4.5
- Update API DocOcrupdate IdOcrPictureBase64 param.
- Update API EkycVerifyupdate FacePictureBase64 param.
update IdOcrPictureBase64 param.
- Update API FaceCompareupdate SourceFacePicture param.
update TargetFacePicture param.
- Update API Initializeadd SecurityLevel param.
update FacePictureBase64 param.


2024-01-25 Version: 1.4.4
- Update API CardOcrupdate IdOcrPictureBase64 param.
- Update API FaceLivenessupdate FacePictureBase64 param.


2024-01-24 Version: 1.4.3
- Generated python 2022-08-09 for Cloudauth-intl.

2024-01-24 Version: 1.4.3
- Generated python 2022-08-09 for Cloudauth-intl.

2024-01-22 Version: 1.4.2
- Generated python 2022-08-09 for Cloudauth-intl.

2024-01-18 Version: 1.4.1
- Generated python 2022-08-09 for Cloudauth-intl.

2023-10-31 Version: 1.4.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-10-20 Version: 1.3.1
- Generated python 2022-08-09 for Cloudauth-intl.

2023-09-22 Version: 1.3.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-09-04 Version: 1.2.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-08-08 Version: 1.1.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-08-07 Version: 1.0.15
- Generated python 2022-08-09 for Cloudauth-intl.

2023-07-19 Version: 1.0.14
- Support ekyc idcard.

2023-07-05 Version: 1.0.13
- Support ekyc idcard.

2023-06-08 Version: 1.0.12
- Support ekyc.

2023-06-01 Version: 1.0.11
- Support ekyc.

2023-05-10 Version: 1.0.10
- Support ekyc.

2023-05-05 Version: 1.0.9
- Support ekyc.

2023-04-19 Version: 1.0.8
- Support ekyc.

2023-01-13 Version: 1.0.7
- Support faceverify.

2022-08-17 Version: 1.0.6
- Support ekyc.

2022-08-16 Version: 1.0.5
- Support ekyc.

2022-08-15 Version: 1.0.4
- Support ekyc.

2022-08-10 Version: 1.0.1
- Support checkResult for ekyc.

2022-08-10 Version: 1.0.0
- Support initialize for ekyc.

==> alibabacloud_cloudauth-intl20220809-3.9.0.tar.gz: alibabacloud_cloudauth-intl20220809-3.9.0/ChangeLog.md <==
2025-07-10 Version: 3.8.2
- Generated python 2022-08-09 for Cloudauth-intl.

2025-07-10 Version: 3.8.1
- Update API Initialize: add request parameters DocName.
- Update API Initialize: add request parameters DocNo.


2025-07-04 Version: 3.8.0
- Support API AddressVerifyIntl.


2025-06-26 Version: 3.7.2
- Update API Initialize: add request parameters ChameleonFrameEnable.


2025-06-16 Version: 3.7.1
- Update API DocOcrMax: add request parameters IdSpoof.
- Update API Initialize: add request parameters Pages.


2025-05-26 Version: 3.7.0
- Support API BankMetaVerifyIntl.


2025-05-20 Version: 3.6.1
- Update API Initialize: add response parameters Body.Result.Protocol.


2025-04-28 Version: 3.6.0
- Support API DocOcrMax.


2025-04-24 Version: 3.5.0
- Support API CredentialVerifyIntl.


2025-04-23 Version: 3.4.2
- Update API Initialize: add request parameters DateOfBirth.
- Update API Initialize: add request parameters DateOfExpiry.
- Update API Initialize: add request parameters DocPageConfig.
- Update API Initialize: add request parameters DocumentNumber.
- Update API Initialize: add request parameters MRTDInput.
- Update API Initialize: add request parameters UseNFC.


2025-04-21 Version: 3.4.1
- Generated python 2022-08-09 for Cloudauth-intl.

2025-04-21 Version: 3.4.0
- Support API CheckVerifyLog.
- Support API DeepfakeDetectIntl.
- Update API FaceGuardRisk: add response parameters Body.Result.GuardRiskScore.


2025-01-09 Version: 3.2.0
- Support API Id2MetaPeriodVerifyIntl.


2025-01-09 Version: 3.1.2
- Generated python 2022-08-09 for Cloudauth-intl.

2024-12-06 Version: 3.1.1
- Update API DocOcr: add param CardSide.
- Update API Initialize: add param AppQualityCheck.


2024-11-21 Version: 3.1.0
- Support API FaceGuardRisk.
- Update API CheckResult: update response param.
- Update API Initialize: add param ProcedurePriority.


2024-10-08 Version: 3.0.0
- Delete API DescribeAddressLabels.
- Delete API DescribeAddressOverview.
- Delete API DescribeMaliciousAddress.
- Delete API DescribeRiskScore.
- Delete API DescribeTransactionsList.
- Delete API DescribeWeb3AddressLabels.
- Delete API DescribeWeb3RiskScore.
- Delete API DescribeWeb3TransactionLabels.
- Update API Initialize: add param ShowGuidePage.


2024-08-29 Version: 2.0.4
- Update API FaceLiveness: update response param.


2024-08-23 Version: 2.0.3
- Update API Initialize: add param ShowAlbumIcon.
- Update API Initialize: add param ShowOcrResult.


2024-06-28 Version: 2.0.2
- Update API DocOcr: add param IdThreshold.
- Update API EkycVerify: add param IdThreshold.
- Update API Initialize: add param DocVideo.
- Update API Initialize: add param IdThreshold.
- Update API Initialize: add param Model.


2024-06-20 Version: 2.0.1
- Update API Initialize: add param ExperienceCode.


2024-04-25 Version: 2.0.0
- Delete API DeletePicture.
- Update API CheckResult: update response param.
- Update API DocOcr: update param IdOcrPictureBase64.
- Update API DocOcr: update param IdOcrPictureUrl.
- Update API DocOcr: update response param.
- Update API EkycVerify: update param DocName.
- Update API EkycVerify: update param DocNo.
- Update API EkycVerify: update param FacePictureBase64.
- Update API EkycVerify: update param FacePictureUrl.
- Update API EkycVerify: update param IdOcrPictureBase64.
- Update API EkycVerify: update param IdOcrPictureUrl.
- Update API EkycVerify: update response param.
- Update API FaceCompare: update param SourceFacePicture.
- Update API FaceCompare: update param SourceFacePictureUrl.
- Update API FaceCompare: update param TargetFacePicture.
- Update API FaceCompare: update param TargetFacePictureUrl.
- Update API FaceLiveness: update param FacePictureBase64.
- Update API FaceLiveness: update param FacePictureUrl.
- Update API FaceLiveness: update response param.
- Update API Id2MetaVerifyIntl: update param IdentifyNum.
- Update API Id2MetaVerifyIntl: update param UserName.
- Update API Initialize: add param StyleConfig.
- Update API Initialize: delete param FlowType.
- Update API Initialize: delete param OperationMode.
- Update API Initialize: delete param Pages.
- Update API Initialize: delete param ProductConfig.
- Update API Initialize: delete param ServiceLevel.
- Update API Initialize: update param FacePictureBase64.
- Update API Initialize: update param FacePictureUrl.
- Update API Mobile3MetaVerifyIntl: update param IdentifyNum.
- Update API Mobile3MetaVerifyIntl: update param Mobile.
- Update API Mobile3MetaVerifyIntl: update param UserName.


2024-02-04 Version: 1.4.5
- Update API DocOcrupdate IdOcrPictureBase64 param.
- Update API EkycVerifyupdate FacePictureBase64 param.
update IdOcrPictureBase64 param.
- Update API FaceCompareupdate SourceFacePicture param.
update TargetFacePicture param.
- Update API Initializeadd SecurityLevel param.
update FacePictureBase64 param.


2024-01-25 Version: 1.4.4
- Update API CardOcrupdate IdOcrPictureBase64 param.
- Update API FaceLivenessupdate FacePictureBase64 param.


2024-01-24 Version: 1.4.3
- Generated python 2022-08-09 for Cloudauth-intl.

2024-01-24 Version: 1.4.3
- Generated python 2022-08-09 for Cloudauth-intl.

2024-01-22 Version: 1.4.2
- Generated python 2022-08-09 for Cloudauth-intl.

2024-01-18 Version: 1.4.1
- Generated python 2022-08-09 for Cloudauth-intl.

2023-10-31 Version: 1.4.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-10-20 Version: 1.3.1
- Generated python 2022-08-09 for Cloudauth-intl.

2023-09-22 Version: 1.3.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-09-04 Version: 1.2.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-08-08 Version: 1.1.0
- Generated python 2022-08-09 for Cloudauth-intl.

2023-08-07 Version: 1.0.15
- Generated python 2022-08-09 for Cloudauth-intl.

2023-07-19 Version: 1.0.14
- Support ekyc idcard.

2023-07-05 Version: 1.0.13
- Support ekyc idcard.

2023-06-08 Version: 1.0.12
- Support ekyc.

2023-06-01 Version: 1.0.11
- Support ekyc.

2023-05-10 Version: 1.0.10
- Support ekyc.

2023-05-05 Version: 1.0.9
- Support ekyc.

2023-04-19 Version: 1.0.8
- Support ekyc.

2023-01-13 Version: 1.0.7
- Support faceverify.

2022-08-17 Version: 1.0.6
- Support ekyc.

2022-08-16 Version: 1.0.5
- Support ekyc.

2022-08-15 Version: 1.0.4
- Support ekyc.

2022-08-10 Version: 1.0.1
- Support checkResult for ekyc.

2022-08-10 Version: 1.0.0
- Support initialize for ekyc.
